AlignOptions

Struct AlignOptions 

pub struct AlignOptions {
Show 38 fields pub index: String, pub reads_unpaired: Vec<String>, pub reads_1: Vec<String>, pub reads_2: Vec<String>, pub sam_file: Option<String>, pub fastq: bool, pub fasta: bool, pub sequences: bool, pub skip: Option<usize>, pub upto: Option<usize>, pub trim5: Option<usize>, pub trim3: Option<usize>, pub seed_mismatches: Option<u8>, pub seed_length: usize, pub end_to_end: bool, pub local: bool, pub no_forward: bool, pub no_reverse: bool, pub match_bonus: Option<i32>, pub mismatch_penalty: i32, pub n_penalty: i32, pub read_gap: Option<String>, pub ref_gap: Option<String>, pub report_alignments: Option<usize>, pub report_all: bool, pub failed_extends: usize, pub seed_sets: usize, pub min_insert: usize, pub max_insert: usize, pub orientation: Option<String>, pub threads: usize, pub reorder: bool, pub print_time: bool, pub quiet: bool, pub no_unaligned: bool, pub no_head: bool, pub no_sq: bool, pub xeq: bool,
}
Ferroux aligner - Fast and sensitive read alignment

Ferroux is an ultrafast and memory-efficient tool for aligning sequencing reads to long reference sequences.

Fields

index: String

Index filename prefix (minus trailing .X.rai)

reads_unpaired: Vec<String>

Files with unpaired reads

reads_1: Vec<String>

Files with #1 mates, paired with files in

reads_2: Vec<String>

Files with #2 mates, paired with files in

sam_file: Option<String>

Output SAM file (default: stdout)

fastq: bool

Query input files are FASTQ .fq/.fastq (default)

fasta: bool

Query input files are (multi-)FASTA .fa/.mfa

sequences: bool

, , are sequences themselves, not files

skip: Option<usize>

Skip the first reads/pairs in the input

upto: Option<usize>

Stop after first reads/pairs

trim5: Option<usize>

Trim bases from 5’/left end of reads

trim3: Option<usize>

Trim bases from 3’/right end of reads

seed_mismatches: Option<u8>

Max # mismatches in seed alignment; can be 0 or 1

seed_length: usize

Length of seed substrings; must be >3, <32

end_to_end: bool

Entire read must align; no clipping

local: bool

Local alignment; ends might be soft clipped

no_forward: bool

Do not align forward (original) version of read

no_reverse: bool

Do not align reverse-complement version of read

match_bonus: Option<i32>

Match bonus (0 for –end-to-end, 2 for –local)

mismatch_penalty: i32

Max penalty for mismatch

n_penalty: i32

Penalty for non-A/C/G/Ts in read/ref

read_gap: Option<String>

Read gap open, extend penalties

ref_gap: Option<String>

Reference gap open, extend penalties

report_alignments: Option<usize>

Report up to alignments per read

report_all: bool

Report all alignments

failed_extends: usize

Give up extending after failed extends

seed_sets: usize

For reads with repetitive seeds, try sets of seeds

min_insert: usize

Minimum fragment length

max_insert: usize

Maximum fragment length

orientation: Option<String>

-1, -2 mates align fw/rev, rev/fw, fw/fw

threads: usize

Number of alignment threads

reorder: bool

Force SAM output order to match input

print_time: bool

Print wall-clock time taken by search phases

quiet: bool

Print nothing to stderr except serious errors

no_unaligned: bool

Suppress SAM records for unaligned reads

no_head: bool

Suppress header lines (@PG, @HD, etc.)

no_sq: bool

Suppress @SQ header lines

xeq: bool

Use ‘=’/‘X’, instead of ‘M,’ to specify matches/mismatches